## Language
[简体中文](https://github.com/kszitt/next-oss/blob/master/README.md)

## Description
Upload the files generated by webpack to the cloud to improve the loading speed  
Currently, only `aliyun` is supported. Based on `ali-oss` module  

## Install
```bash
npm install next-oss --save-dev
```

## Compatibility
### Node
Node.js >= 10.10.0 required

## Non `next` framework
#### Add command
```jsx
// package.json
{
  "folder": "<Cloud folder>",
  "OSSDomainName": "<Cloud domain name>",
  "OSSProduction": <:boolean>, // Whether OSS is used in production mode
  "scripts": {
    "build": "cross-env NODE_ENV=production webpack",  //  Please install cross env yourself
  }
}
```
#### Webpack profile
```jsx
// webpack.config.js
const NextOss = require('next-oss');

...
plugins: [
  ...
  new NextOss({
    disable: process.env.NODE_ENV !== "production",
    aliyun: {
      region: "<OSS region>",
      accessKeyId: "<Your accessKeyId>",
      accessKeySecret: "<Your accessKeySecret>",
      bucket: "<Your bucket name>"
    }
  })
]
```
#### deploy
``` hash
npm run build
// Deploy the index.html file under the package folder to the server to ensure access to
```
## `next` framework
#### Add command
```jsx
// package.json
{
  "OSSDomainName": "<Cloud domain name>",
  "OSSFolder": "<Cloud folder>",
  "OSSProduction": <:boolean>, // Whether OSS is used in production mode
  "scripts": {
    "build": "cross-env NODE_ENV=production next build",  // build command (Please install cross env yourself)
    "start": "cross-env NODE_ENV=production node server.js"   // start service (You cannot use `next start` here. You need to customize the server)
  }
}
```
#### Custom server
```jsx
// server.js
const express = require('express');
const next = require('next');
const {OSSFolder, OSSDomainName, OSSProduction} = require('./package.json');
const { NODE_ENV, PORT=3000 } = process.env;
const dev = NODE_ENV !== 'production';
const Prod = NODE_ENV === "production";
const app = next({dir: '.', dev});

// Use OSS or not（Only the production mode can use OSS, and the development mode is invalid）
if(Prod ? OSSProduction : false){
  app.setAssetPrefix(`${OSSDomainName}/${OSSFolder}/`);
}

app.prepare().then(() => {
    const server = express();

    server.listen(PORT, (err) => {
      if (err) {
        throw err
      }
      console.log(`> Ready on port ${PORT} [${NODE_ENV}]`);
    })
  }).catch((ex) => {
    console.log('An error occurred, unable to start the server')
    console.log(ex)
  });
```
#### Webpack profile
```jsx
// next.config.js
const NextOss = require('next-oss');
const {OSSFolder, OSSDomainName, OSSProduction} = require('./package.json');
const withPlugins = require ("next-compose-plugins");
const { NODE_ENV } = process.env;
const Prod = NODE_ENV === "production";

...
const nextConfig = {
  webpack: (config, options) => {
    ...
    let NextOssOptions = {
      disable: Prod ? !OSSProduction : true,  // Only the production mode can use OSS, and the development mode is invalid
      aliyun: {
        region: "<OSS region>",
        accessKeyId: "<Your accessKeyId>",
        accessKeySecret: "<Your accessKeySecret>",
        bucket: "<Your bucket name>"
      }
    };
    if(!NextOssOptions.disable) options.config.assetPrefix = `${OSSDomainName}/"${OSSFolder}/`;
    config.plugins.push(
      new NextOss(NextOssOptions)
    );

    return config;
  }
};

module.exports = withPlugins([...], nextConfig);
```
#### deploy
``` hash
npm run build
npm run start
```

## NextOSS(options):
- `aliyun` - Initialize Aliyun cloud OSS information
- `disable` - Is it disable? default`false`. Development mode does not work
- `deletePrevBuildFile` - Delete previous versions of cloud, default`false`
- `log` - Show log or not, default`true
- `cover` - Whether picture and font files are overwritten, default `true`。It is recommended to use [hash] as the file name, and then set it to `false` to improve the upload speed.
